@@ -3,12 +3,14 @@ BEGIN {
   $POE::Component::IRC::Plugin::FollowTail::AUTHORITY = 'cpan:HINRIK';
 }
 BEGIN {
-  $POE::Component::IRC::Plugin::FollowTail::VERSION = '6.56';
+  $POE::Component::IRC::Plugin::FollowTail::VERSION = '6.57';
 }
 
 use strict;
 use warnings FATAL => 'all';
 use Carp;
+use Cwd qw(abs_path);
+use File::Glob ':glob';
 use POE qw(Wheel::FollowTail);
 use POE::Component::IRC::Plugin qw( :ALL );
 
@@ -18,9 +20,10 @@ sub new {
     my %args = @_;
     $args{lc $_} = delete $args{$_} for keys %args;
 
-    if (!$args{filename} || ! -e $args{filename}) {
-        die "$package requires a valid 'filename' attribute";
-    }
+    die "$package requires a 'filename' attribute" if !defined $args{filename};
+    $args{filename} = bsd_glob($args{filename});
+    die "File '$args{filename}' does not exist" if !-e $args{filename};
+    $args{filename} = abs_path($args{filename});
 
     return bless \%args, $package;
 }
